@@ -25,7 +25,6 @@
 #include "aboutdialog.h"
 #include "vlcbrowseelement.h"
 #include "appsettings.h"
-#include "favouritesmainwindow.h"
 
 BrowseMainWindow::BrowseMainWindow(QWidget *parent) :
         QMainWindow(parent),
@@ -33,7 +32,6 @@ BrowseMainWindow::BrowseMainWindow(QWidget *parent) :
 {
 
     ui->setupUi(this);
-    mFavouritesMainWindow = new FavouritesMainWindow;
     mCurrentDir = "~/"; //AppSettings::getHomeDirectory().path; // This works on win as well as linux, would guess mac too.
     setWindowTitle("Vlc remote");
 
@@ -52,16 +50,7 @@ BrowseMainWindow::BrowseMainWindow(QWidget *parent) :
     ui->playButton->setDisabled(true);
     ui->addButton->setDisabled(true);
 
-
-#if defined(Q_WS_S60) || defined(Q_WS_MAEMO_5)
-
-    mFavouritesMainWindow->setParent(this);
-    mFavouritesMainWindow->setAttribute(Qt::WA_Maemo5StackedWindow);
-    setAttribute(Qt::WA_Maemo5StackedWindow);
-    mFavouritesMainWindow->setWindowFlags(mFavouritesMainWindow->windowFlags() | Qt::Window);
-
-#endif
-
+    connect(ui->listWidget,SIGNAL(doubleClicked(QModelIndex)),this,SLOT(onBrowse()));
     connect(ui->browseButton,SIGNAL(clicked()),this,SLOT(onBrowse()));
     connect(ui->addButton,SIGNAL(clicked()),this,SLOT(onAddToPlaylist()));
     connect(ui->playButton,SIGNAL(clicked()),this,SLOT(onPlay()));
@@ -135,8 +124,10 @@ void BrowseMainWindow::setHomeFolder() {
     }
 }
 void BrowseMainWindow::showFavourites() {
-    mFavouritesMainWindow->show();
-    mFavouritesMainWindow->init();
+    emit showFavouritesWindow();
+#if defined(Q_WS_S60) || defined(Q_WS_MAEMO_5)
+    this->hide();
+#endif
 }
 void BrowseMainWindow::setFavourite() {
     if (0 < mCurrentElement.name.length() && (0 == QString::compare("directory", mCurrentElement.type) || 0 == QString::compare("dir", mCurrentElement.type))) {
@@ -212,14 +203,12 @@ void BrowseMainWindow::onAddToPlaylist() {
     QUrl url = QUrl("http://"+mIp+"/requests/status.xml?command=in_enqueue");
     url.addEncodedQueryItem(QByteArray("input"), QUrl::toPercentEncoding(mCurrentElement.path.replace("\\", "\\\\").replace("'", "\\'")));
     mNetManager->get(QNetworkRequest(url));
-    //mNetManager->get(QNetworkRequest(QUrl("http://"+mIp+"/requests/status.xml?command=in_enqueue&input=" + mCurrentElement.path.replace("\\", "\\\\"))));
 }
 
 void BrowseMainWindow::onPlay() {
     QUrl url = QUrl("http://"+mIp+"/requests/status.xml?command=in_play");
     url.addEncodedQueryItem(QByteArray("input"), QUrl::toPercentEncoding(mCurrentElement.path.replace("\\", "\\\\").replace("'", "\\'")));
     mNetManager->get(QNetworkRequest(url));
-    //mNetManager->get(QNetworkRequest(QUrl("http://"+mIp+"/requests/status.xml?command=in_play&input=" + mCurrentElement.path.replace("\\", "\\\\"))));
 }
 
 void BrowseMainWindow::browseDirectory(QString dir) {
@@ -227,7 +216,6 @@ void BrowseMainWindow::browseDirectory(QString dir) {
     QUrl url = QUrl("http://"+mIp+"/requests/browse.xml");
     url.addEncodedQueryItem(QByteArray("dir"), QUrl::toPercentEncoding(dir));
     QNetworkReply * reply = mNetManager->get(QNetworkRequest(url));
-    //QNetworkReply * reply =  mNetManager->get(QNetworkRequest(QUrl("http://"+mIp+"/requests/browse.xml?dir=" + dir.replace("&", "%26").replace("\\", "\\\\"))));
 #if defined(Q_WS_S60) || defined(Q_WS_MAEMO_5)
     this->setAttribute(Qt::WA_Maemo5ShowProgressIndicator, true);
 #endif
@@ -362,9 +350,11 @@ void BrowseMainWindow::updateList() {
                           0 == QString::compare(dir.extension, "ogg")  ||
                           0 == QString::compare(dir.extension, "oga")  ||
                           0 == QString::compare(dir.extension, "wav")  ||
+                          0 == QString::compare(dir.extension, "bmu")  ||
+                          0 == QString::compare(dir.extension, "wma")  ||
                           0 == QString::compare(dir.extension, "flac")  ) {
                     item_good = true;
-                    item = new QListWidgetItem(icon_audio, dir.name, ui->listWidget, 0); // .mp3, .m4a, .ogg, .oga, .wav, .flac
+                    item = new QListWidgetItem(icon_audio, dir.name, ui->listWidget, 0); // .mp3, .m4a, .ogg, .oga, .wav, .bmu, .wma, .flac
                 }
                 else if ( 0 == QString::compare(dir.extension, "m3u")  ||
                           0 == QString::compare(dir.extension, "wpl")  ||
@@ -402,8 +392,13 @@ void BrowseMainWindow::updateList() {
                         item = new QListWidgetItem(icon_flash, dir.name, ui->listWidget, 0);
                     }
                     else {
-                        item_good = false;
-                        //item = new QListWidgetItem(icon_unknown, dir.name, ui->listWidget, 0);
+                        if (AppSettings::getShowUnknownFileTypes()) {
+                            item_good = true;
+                            item = new QListWidgetItem(icon_unknown, dir.name, ui->listWidget, 0);
+                        }
+                        else {
+                            item_good = false;
+                        }
                     }
                 }
             }
