@@ -24,7 +24,15 @@
 #include <QTimer>
 #include "playlistmainwindow.h"
 #include "browsemainwindow.h"
+#include "favouritesmainwindow.h"
 #include "vlcstatus.h"
+#if defined(Q_WS_S60) || defined(Q_WS_MAEMO_5)
+  #include <mce/dbus-names.h>
+  #include <mce/mode-names.h>
+  #include <QDBusConnection>
+  #include <QDBusMessage>
+  #include <QDBusInterface>
+#endif
 
 namespace Ui {
     class PlayerMainWindow;
@@ -37,9 +45,12 @@ public:
     ~PlayerMainWindow();
 
 public slots:
+    void displayStateChanged(const QDBusMessage &message);
     void askStatus();
+    void showSettings();
     void showConfig();
     void showAbout();
+    void showFavourites();
     void play();
     void playpause();
     void stop();
@@ -58,6 +69,7 @@ public slots:
     void finished(QNetworkReply * reply);
     void error(QNetworkReply::NetworkError code);
     void readReady();
+    void updateFromSettings();
     void orientationChanged();
     void setPortrait();
     void setLandscape();
@@ -67,14 +79,17 @@ public slots:
 
 protected slots:
     void parseXmlStatus();
+
 protected:
     void changeEvent(QEvent *e);
+    void closeEvent(QCloseEvent *);
 
 
 private:
     Ui::PlayerMainWindow *ui;
     PlayListMainWindow * mPlayListMainWindow;
     BrowseMainWindow * mBrowserMainWindow;
+    FavouritesMainWindow * mFavouritesMainWindow;
     QNetworkAccessManager * mNetManager;
     QString mIp;
     QTimer * mTimer;
@@ -84,7 +99,9 @@ private:
     QByteArray mResponse;
     bool mIsLandscape;
     bool mHasImage;
-
+    bool mIsFirstStatusCall;
+    static QDBusConnection dBusConnection;
+    static QDBusInterface* dBusInterface;
 };
 
 #endif // PLAYERMAINWINDOW_H
