@@ -61,6 +61,7 @@ PlayListMainWindow::PlayListMainWindow(QWidget *parent) :
     ui->removeButton->setDisabled(true);
     ui->playButton->setDisabled(true);
 
+    connect(ui->listWidget,SIGNAL(doubleClicked(QModelIndex)),this,SLOT(onPlay()));
     connect(ui->playButton,SIGNAL(clicked()),this,SLOT(onPlay()));
     connect(ui->removeButton,SIGNAL(clicked()),this,SLOT(onRemove()));
     connect(ui->repeatButton,SIGNAL(clicked()),this,SLOT(onRepeat()));
@@ -354,8 +355,10 @@ void PlayListMainWindow::updateList() {
                     0 == QString::compare(el.extension, "ogg")  ||
                     0 == QString::compare(el.extension, "oga")  ||
                     0 == QString::compare(el.extension, "wav")  ||
+                    0 == QString::compare(el.extension, "bmu")  ||
+                    0 == QString::compare(el.extension, "wma")  ||
                     0 == QString::compare(el.extension, "flac")  ) {
-              item = new QListWidgetItem(icon_audio, el.name, ui->listWidget, LIST_ITEM_TYPE_OFFSET + el.id); // .mp3, .m4a, .ogg, .oga, .wav, .flac
+              item = new QListWidgetItem(icon_audio, el.name, ui->listWidget, LIST_ITEM_TYPE_OFFSET + el.id); // .mp3, .m4a, .ogg, .oga, .wav, .bmu, .wma, .flac
           }
           else if ( 0 == QString::compare(el.extension, "m3u")  ||
                     0 == QString::compare(el.extension, "wpl")  ||
